==> scikit-llm-0.2.0.tar.gz: scikit-llm-0.2.0/tests/test_gpt_few_shot_clf.py <==
import json
import random
import unittest
from unittest.mock import MagicMock, patch

import numpy as np

from skllm.models.gpt_dyn_few_shot_clf import DynamicFewShotGPTClassifier
from skllm.models.gpt_few_shot_clf import FewShotGPTClassifier


class TestFewShotGPTClassifier(unittest.TestCase):
    def get_mock_clf_model(self, clf="dynamic"):
        if clf == "dynamic":
            clf = DynamicFewShotGPTClassifier(
                openai_key="mock_key", openai_org="mock_org"
            )
        else:
            clf = FewShotGPTClassifier(
                openai_key="mock_key", openai_org="mock_org"
            )  # Mock keys
        X = np.array(["text1", "text2", "text3"])
        y = np.array(["class1", "class2", "class1"])
        clf.fit(X, y)

        self.assertEqual(set(clf.classes_), set(["class1", "class2"]))
        self.assertEqual(clf.probabilities_, [2 / 3, 1 / 3])
        return clf

    def test_prompt_generation(self):
        clf = self.get_mock_clf_model("few_shot")
        prompt = clf._get_prompt("new_text")
        self.assertIn("text1", prompt)
        self.assertIn("text2", prompt)
        self.assertIn("text3", prompt)
        self.assertIn("class1", prompt)
        self.assertIn("class2", prompt)
        self.assertIn("new_text", prompt)

    def test_fit(self):
        clf = self.get_mock_clf_model("few_shot")
        X = ["text1", "text2", "text3"]
        y = ["class1", "class2", "class1"]
        self.assertEqual(len(clf.training_data_[0]), len(X))
        self.assertEqual(len(clf.training_data_[1]), len(y))
        for x in X:
            self.assertIn(x, clf.training_data_[0])
        for y_ in y:
            self.assertIn(y_, clf.training_data_[1])

    # TODO Add prompt generation test for dynamic few shot

    # TODO Add tests for dynamic few_show fit

==> scikit-llm-0.4.2.tar.gz: scikit-llm-0.4.2/tests/test_gpt_few_shot_clf.py <==
import json
import random
import unittest
from unittest.mock import MagicMock, patch

import numpy as np

from skllm import DynamicFewShotGPTClassifier, FewShotGPTClassifier


class TestFewShotGPTClassifier(unittest.TestCase):
    def get_mock_clf_model(self, clf="dynamic"):
        if clf == "dynamic":
            clf = DynamicFewShotGPTClassifier(
                openai_key="mock_key", openai_org="mock_org"
            )
        else:
            clf = FewShotGPTClassifier(
                openai_key="mock_key", openai_org="mock_org"
            )  # Mock keys
        X = np.array(["text1", "text2", "text3"])
        y = np.array(["class1", "class2", "class1"])
        clf.fit(X, y)

        self.assertEqual(set(clf.classes_), set(["class1", "class2"]))
        self.assertEqual(clf.probabilities_, [2 / 3, 1 / 3])
        return clf

    def test_prompt_generation(self):
        clf = self.get_mock_clf_model("few_shot")
        prompt = clf._get_prompt("new_text")
        self.assertIn("text1", prompt)
        self.assertIn("text2", prompt)
        self.assertIn("text3", prompt)
        self.assertIn("class1", prompt)
        self.assertIn("class2", prompt)
        self.assertIn("new_text", prompt)

    def test_fit(self):
        clf = self.get_mock_clf_model("few_shot")
        X = ["text1", "text2", "text3"]
        y = ["class1", "class2", "class1"]
        self.assertEqual(len(clf.training_data_[0]), len(X))
        self.assertEqual(len(clf.training_data_[1]), len(y))
        for x in X:
            self.assertIn(x, clf.training_data_[0])
        for y_ in y:
            self.assertIn(y_, clf.training_data_[1])

    # TODO Add prompt generation test for dynamic few shot

    # TODO Add tests for dynamic few_show fit
